<?php

/**
 * Ruki: Featured Post Settings
 *
 * @package WordPress
 * @subpackage Ruki
 * @since 1.0
 * @version 1.5
 */

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

// Register customizer settings

function ruki_featured_posts_customize_register( $wp_customize ) {

		// ========================================================
		// Category Featured
		// ========================================================

		$wp_customize->add_panel( 'ruki_featured_posts', array(
		  'title' => esc_html__( 'Ruki: Featured Posts', 'ruki-featured-posts' ),
		  'description' => esc_html__( 'Configure Featured Posts', 'ruki-featured-posts'),
		  'priority' => 150,
		  ) );

		$wp_customize->add_section( 'ruki_category_featured_settings', array(
			'title'    => esc_html__( 'Category Featured Posts ', 'ruki-featured-posts' ),
			'panel'    => 'ruki_featured_posts',
			'priority' => 160,
		) );

		/**
		 * Display Posts
		 */
		$wp_customize->add_setting( 'ruki_category_featured', array(
			'default'           => true,
			'sanitize_callback' => 'ruki_featured_posts_sanitize_checkbox',
		) );

		$wp_customize->add_control( 'ruki_category_featured', array(
			'label'       => esc_html__( 'Display Featured Posts', 'ruki-featured-posts' ),
			'section'     => 'ruki_category_featured_settings',
			'type'        => 'checkbox',
		) );

		if ( apply_filters( 'ruki_featured_posts_full_width_support', false ) ) :

			$wp_customize->add_setting( 'ruki_category_featured_full_width', array(
				'default'           => false,
				'sanitize_callback' => 'ruki_featured_posts_sanitize_checkbox',
			) );

			$wp_customize->add_control( 'ruki_category_featured_full_width', array(
				'label'       => esc_html__( 'Full Width', 'ruki-featured-posts' ),
				'section'     => 'ruki_category_featured_settings',
				'type'        => 'checkbox',
			) );

		endif;

		// Add Setting
		$wp_customize->add_setting( 'ruki_category_featured_title', array(
			'default'           => '',
			'sanitize_callback' => 'ruki_featured_posts_sanitize_text',
		) );

		// Control Options
		$wp_customize->add_control( 'ruki_category_featured_title', array(
			'label'       => esc_html__( 'Title', 'ruki-featured-posts' ),
			'section'     => 'ruki_category_featured_settings',
			'type'        => 'text',
		) );

		/**
		 * Number of Posts
		 */
		$wp_customize->add_setting( 'ruki_category_featured_num', array(
			'default'           => 3,
			'sanitize_callback' => 'absint',
		) );

		$wp_customize->add_control( 'ruki_category_featured_num', array(
			'label'       => esc_html__( 'Number of posts', 'ruki-featured-posts' ),
			'section'     => 'ruki_category_featured_settings',
			'type'        => 'number',
			'input_attrs' => array(
		        'min'   => 1,
		        'max'   => apply_filters( 'ruki_featured_posts_max_posts', 999 ),
		    ),
		) );

		/**
		 * Number of Columns
		 */
		$wp_customize->add_setting( 'ruki_category_featured_cols', array(
			'default'           => 3,
			'sanitize_callback' => 'absint',
		) );

		if ( apply_filters( 'ruki_featured_posts_theme_supports_carousel', false )) :

			$wp_customize->add_control( 'ruki_category_featured_cols', array(
				'label'       => esc_html__( 'Number of columns/slides', 'ruki-featured-posts' ),
				'section'     => 'ruki_category_featured_settings',
				'type'        => 'number',
				'input_attrs' => array(
			        'min'   => 1,
			        'max'   => apply_filters( 'ruki_featured_posts_max_cols', 3 ),
			    ),
			) );

		else:

			$wp_customize->add_control( 'ruki_category_featured_cols', array(
				'label'       => esc_html__( 'Number of columns', 'ruki-featured-posts' ),
				'section'     => 'ruki_category_featured_settings',
				'type'        => 'number',
				'input_attrs' => array(
			        'min'   => 1,
			        'max'   => apply_filters( 'ruki_featured_posts_max_cols', 3 ),
			    ),
			) );


		endif;


		/**
		 * Loop style
		 */
		$wp_customize->add_setting( 'ruki_category_featured_loop_style', array(
			'default'           => 'default',
			'sanitize_callback' => 'ruki_sanitize_loop_style',
		) );

		$wp_customize->add_control( 'ruki_category_featured_loop_style', array(
			'label'       => esc_html__( 'Post Style', 'ruki-featured-posts' ),
			'section'     => 'ruki_category_featured_settings',
			'type'        => 'select',
			'choices'     => array(
				'default' => esc_html__( 'Default', 'ruki-featured-posts' ),
				'cover' => esc_html__( 'Cover', 'ruki-featured-posts' ), // Remove this with a filter if not required for a theme
			),
		) );

		if ( apply_filters( 'ruki_featured_posts_theme_supports_carousel', false ) ):

			/**
			 * Layout
			 */
			$wp_customize->add_setting( 'ruki_category_featured_layout', array(
				'default'           => 'grid',
				'sanitize_callback' => 'ruki_sanitize_featured_posts_layout',
			) );

			$wp_customize->add_control( 'ruki_category_featured_layout', array(
				'label'       => esc_html__( 'Layout', 'ruki-featured-posts' ),
				'section'     => 'ruki_category_featured_settings',
				'type'        => 'select',
				'choices'     => array(
					'grid' => esc_html__( 'Grid', 'ruki-featured-posts' ),
					'carousel' => esc_html__( 'Carousel', 'ruki-featured-posts' ),
				),
			) );

		endif;

		$wp_customize->add_setting( 'ruki_category_featured_image_size', array(
			'default'           => 'landscape',
			'sanitize_callback' => 'ruki_sanitize_aspect_ratio',
		) );

		$wp_customize->add_control( 'ruki_category_featured_image_size', array(
			'label'       => esc_html__( 'Thumbnail Size', 'ruki-featured-posts' ),
			'section'     => 'ruki_category_featured_settings',
			'type'        => 'select',
			'choices'     => array(
				'landscape' => esc_html__( 'Landscape', 'ruki-featured-posts' ),
				'portrait' => esc_html__( 'Portrait', 'ruki-featured-posts' ),
				'square' => esc_html__( 'Square', 'ruki-featured-posts' ),
			),
		) );

		$wp_customize->add_setting( 'ruki_category_featured_arrows', array(
			'default'           => true,
			'sanitize_callback' => 'ruki_featured_posts_sanitize_checkbox',
		) );

		$wp_customize->add_control( 'ruki_category_featured_arrows', array(
			'label'       => esc_html__( 'Show Prev/Next Arrows', 'ruki-featured-posts' ),
			'section'     => 'ruki_category_featured_settings',
			'type'        => 'checkbox',
		) );

		$wp_customize->add_setting( 'ruki_category_featured_thumbnail', array(
			'default'           => true,
			'sanitize_callback' => 'ruki_featured_posts_sanitize_checkbox',
		) );

		$wp_customize->add_control( 'ruki_category_featured_thumbnail', array(
			'label'       => esc_html__( 'Thumbnail', 'ruki-featured-posts' ),
			'section'     => 'ruki_category_featured_settings',
			'type'        => 'checkbox',
		) );

		$wp_customize->add_setting( 'ruki_category_featured_video', array(
			'default'           => true,
			'sanitize_callback' => 'ruki_featured_posts_sanitize_checkbox',
		) );

		$wp_customize->add_control( 'ruki_category_featured_video', array(
			'label'       => esc_html__( 'Video', 'ruki-featured-posts' ),
			'section'     => 'ruki_category_featured_settings',
			'type'        => 'checkbox',
		) );

		/**
		 * Entry title/meta
		 */

		$wp_customize->add_setting( 'ruki_category_featured_excerpt', array(
			'default'           => false,
			'sanitize_callback' => 'ruki_featured_posts_sanitize_checkbox',
		) );

		$wp_customize->add_control( 'ruki_category_featured_excerpt', array(
			'label'       => esc_html__( 'Excerpt', 'ruki-featured-posts' ),
			'section'     => 'ruki_category_featured_settings',
			'type'        => 'checkbox',
		) );

		$wp_customize->add_setting( 'ruki_category_featured_read_more', array(
			'default'           => false,
			'sanitize_callback' => 'ruki_featured_posts_sanitize_checkbox',
		) );

		$wp_customize->add_control( 'ruki_category_featured_read_more', array(
			'label'       => esc_html__( 'Read More', 'ruki-featured-posts' ),
			'section'     => 'ruki_category_featured_settings',
			'type'        => 'checkbox',
		) );

		// Entry Title
		$wp_customize->add_setting( 'ruki_category_featured_entry_title', array(
			'default'           => true,
			'sanitize_callback' => 'ruki_featured_posts_sanitize_checkbox',
		) );

		$wp_customize->add_control( 'ruki_category_featured_entry_title', array(
			'label'       => esc_html__( 'Entry Title', 'ruki-featured-posts' ),
			'section'     => 'ruki_category_featured_settings',
			'type'        => 'checkbox',
		) );

		// Author Meta
		$wp_customize->add_setting( 'ruki_category_featured_entry_meta_by', array(
			'default'           => true,
			'sanitize_callback' => 'ruki_featured_posts_sanitize_checkbox',
		) );

		$wp_customize->add_control( 'ruki_category_featured_entry_meta_by', array(
			'label'       => esc_html__( '"by"', 'ruki-featured-posts' ),
			'section'     => 'ruki_category_featured_settings',
			'type'        => 'checkbox',
		) );

		// Author Meta
		$wp_customize->add_setting( 'ruki_category_featured_entry_meta_author', array(
			'default'           => true,
			'sanitize_callback' => 'ruki_featured_posts_sanitize_checkbox',
		) );

		$wp_customize->add_control( 'ruki_category_featured_entry_meta_author', array(
			'label'       => esc_html__( 'Author', 'ruki-featured-posts' ),
			'section'     => 'ruki_category_featured_settings',
			'type'        => 'checkbox',
		) );

		// Author Avatar
		$wp_customize->add_setting( 'ruki_category_featured_entry_meta_author_avatar', array(
			'default'           => false,
			'sanitize_callback' => 'ruki_featured_posts_sanitize_checkbox',
		) );

		$wp_customize->add_control( 'ruki_category_featured_entry_meta_author_avatar', array(
			'label'       => esc_html__( 'Author Avatar', 'ruki-featured-posts' ),
			'section'     => 'ruki_category_featured_settings',
			'type'        => 'checkbox',
		) );

		// Category Meta
		$wp_customize->add_setting( 'ruki_category_featured_entry_meta_category', array(
			'default'           => true,
			'sanitize_callback' => 'ruki_featured_posts_sanitize_checkbox',
		) );

		$wp_customize->add_control( 'ruki_category_featured_entry_meta_category', array(
			'label'       => esc_html__( 'Category', 'ruki-featured-posts' ),
			'section'     => 'ruki_category_featured_settings',
			'type'        => 'checkbox',
		) );

		// Date Meta
		$wp_customize->add_setting( 'ruki_category_featured_entry_meta_date', array(
			'default'           => true,
			'sanitize_callback' => 'ruki_featured_posts_sanitize_checkbox',
		) );

		$wp_customize->add_control( 'ruki_category_featured_entry_meta_date', array(
			'label'       => esc_html__( 'Date', 'ruki-featured-posts' ),
			'section'     => 'ruki_category_featured_settings',
			'type'        => 'checkbox',
		) );

		// Date Meta
		if ( function_exists( 'ruki_read_time' ) ) :
			$wp_customize->add_setting( 'ruki_category_featured_entry_meta_read_time', array(
				'default'           => false,
				'sanitize_callback' => 'ruki_featured_posts_sanitize_checkbox',
			) );

			$wp_customize->add_control( 'ruki_category_featured_entry_meta_read_time', array(
				'label'       => esc_html__( 'Read Time', 'ruki-featured-posts' ),
				'section'     => 'ruki_category_featured_settings',
				'type'        => 'checkbox',
			) );
		endif;

		// Comments Meta
		$wp_customize->add_setting( 'ruki_category_featured_entry_meta_comment_count', array(
			'default'           => true,
			'sanitize_callback' => 'ruki_featured_posts_sanitize_checkbox',
		) );

		$wp_customize->add_control( 'ruki_category_featured_entry_meta_comment_count', array(
			'label'       => esc_html__( 'Comment Count', 'ruki-featured-posts' ),
			'section'     => 'ruki_category_featured_settings',
			'type'        => 'checkbox',
		) );

		// Post format icons
		$wp_customize->add_setting( 'ruki_category_featured_post_format_icons', array(
			'default'           => true,
			'sanitize_callback' => 'ruki_featured_posts_sanitize_checkbox',
		) );

		// Control Options
		$wp_customize->add_control( 'ruki_category_featured_post_format_icons', array(
			'label'       => esc_html__( 'Show Post Format Icons', 'ruki-featured-posts' ),
			'section'     => 'ruki_category_featured_settings',
			'type'        => 'checkbox',
		) );

		// Option to exclude from pages
		$wp_customize->add_setting( 'ruki_category_featured_exclude_duplicate', array(
			'default'           => '',
			'sanitize_callback' => 'ruki_featured_posts_sanitize_checkbox',
		) );

		// Control Options
		$wp_customize->add_control( 'ruki_category_featured_exclude_duplicate', array(
			'label'       => esc_html__( 'Exclude Featured Posts From Loop', 'ruki-featured-posts' ),
			'section'     => 'ruki_category_featured_settings',
			'type'        => 'checkbox',
		) );

		// Added in version 1.4

		if ( apply_filters( 'ruki_category_featured_background', false ) ) :

			$wp_customize->add_setting( 'ruki_category_featured_background', array(
				'default'           => '',
				'transport' => 'refresh',
				'sanitize_callback' => 'sanitize_hex_color',
			) );

			// Control Options
			$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'ruki_category_featured_background', array(
		      'section' => 'ruki_category_featured_settings',
		      'label'   => esc_html__( 'Background Color', 'ruki-featured-posts' ),
		    ) ) );

		    $wp_customize->add_setting( 'ruki_category_featured_title_color', array(
				'default'           => '',
				'transport' => 'refresh',
				'sanitize_callback' => 'sanitize_hex_color',
			) );

			// Control Options
			$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'ruki_category_featured_title_color', array(
		      'section' => 'ruki_category_featured_settings',
		      'label'   => esc_html__( 'Title Color', 'ruki-featured-posts' ),
		    ) ) );

		    if ( apply_filters( 'ruki_featured_posts_supports_card', false ) ) :

			    $wp_customize->add_setting( 'ruki_category_featured_card_background', array(
					'default'           => '',
					'transport' => 'refresh',
					'sanitize_callback' => 'sanitize_hex_color',
				) );

				// Control Options
				$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'ruki_category_featured_card_background', array(
			      'section' => 'ruki_category_featured_settings',
			      'label'   => esc_html__( 'Post Background Color', 'ruki-featured-posts' ),
			    ) ) );

			endif;

		    $wp_customize->add_setting( 'ruki_category_featured_entry_title_link_color', array(
				'default'           => '',
				'transport' => 'refresh',
				'sanitize_callback' => 'sanitize_hex_color',
			) );

			// Control Options
			$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'ruki_category_featured_entry_title_link_color', array(
		      'section' => 'ruki_category_featured_settings',
		      'label'   => esc_html__( 'Entry Title Link Color', 'ruki-featured-posts' ),
		    ) ) );

		    $wp_customize->add_setting( 'ruki_category_featured_entry_meta_color', array(
				'default'           => '',
				'transport' => 'refresh',
				'sanitize_callback' => 'sanitize_hex_color',
			) );

			// Control Options
			$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'ruki_category_featured_entry_meta_color', array(
		      'section' => 'ruki_category_featured_settings',
		      'label'   => esc_html__( 'Entry Meta Color', 'ruki-featured-posts' ),
		    ) ) );

		    $wp_customize->add_setting( 'ruki_category_featured_entry_meta_link_color', array(
				'default'           => '',
				'transport' => 'refresh',
				'sanitize_callback' => 'sanitize_hex_color',
			) );

			// Control Options
			$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'ruki_category_featured_entry_meta_link_color', array(
		      'section' => 'ruki_category_featured_settings',
		      'label'   => esc_html__( 'Entry Meta Link Color', 'ruki-featured-posts' ),
		    ) ) );

		    $wp_customize->add_setting( 'ruki_category_featured_entry_content_color', array(
				'default'           => '',
				'transport' => 'refresh',
				'sanitize_callback' => 'sanitize_hex_color',
			) );

			// Control Options
			$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'ruki_category_featured_entry_content_color', array(
		      'section' => 'ruki_category_featured_settings',
		      'label'   => esc_html__( 'Excerpt Color', 'ruki-featured-posts' ),
		    ) ) );

		     $wp_customize->add_setting( 'ruki_category_featured_continue_reading_color', array(
				'default'           => '',
				'transport' => 'refresh',
				'sanitize_callback' => 'sanitize_hex_color',
			) );

			// Control Options
			$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'ruki_category_featured_continue_reading_color', array(
		      'section' => 'ruki_category_featured_settings',
		      'label'   => esc_html__( 'Continue Reading Color', 'ruki-featured-posts' ),
		    ) ) );

		    $wp_customize->add_setting( 'ruki_category_featured_arrows_background', array(
				'default'           => '',
				'transport' => 'refresh',
				'sanitize_callback' => 'sanitize_hex_color',
			) );

			// Control Options
			$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'ruki_category_featured_arrows_background', array(
		      'section' => 'ruki_category_featured_settings',
		      'label'   => esc_html__( 'Prev/Next Arrows Background', 'ruki-featured-posts' ),
		    ) ) );

		    $wp_customize->add_setting( 'ruki_category_featured_arrows_color', array(
				'default'           => '',
				'transport' => 'refresh',
				'sanitize_callback' => 'sanitize_hex_color',
			) );

			// Control Options
			$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'ruki_category_featured_arrows_color', array(
		      'section' => 'ruki_category_featured_settings',
		      'label'   => esc_html__( 'Prev/Next Arrows Color', 'ruki-featured-posts' ),
		    ) ) );

		endif;

		// ========================================================
		// Home Featured
		// ========================================================

		$wp_customize->add_section( 'ruki_home_featured_settings', array(
			'title'    => esc_html__( 'Home Featured Posts ', 'ruki-featured-posts' ),
			'panel'    => 'ruki_featured_posts',
			'priority' => 160,
		) );

		/**
		 * Display Featured Posts
		 */
		$wp_customize->add_setting( 'ruki_home_featured', array(
			'default'           => true,
			'sanitize_callback' => 'ruki_featured_posts_sanitize_checkbox',
		) );

		$wp_customize->add_control( 'ruki_home_featured', array(
			'label'       => esc_html__( 'Display Featured Posts', 'ruki-featured-posts' ),
			'section'     => 'ruki_home_featured_settings',
			'type'        => 'checkbox',
		) );

		if ( apply_filters( 'ruki_featured_posts_full_width_support', false ) ) :

			$wp_customize->add_setting( 'ruki_home_featured_full_width', array(
				'default'           => false,
				'sanitize_callback' => 'ruki_featured_posts_sanitize_checkbox',
			) );

			$wp_customize->add_control( 'ruki_home_featured_full_width', array(
				'label'       => esc_html__( 'Full Width', 'ruki-featured-posts' ),
				'section'     => 'ruki_home_featured_settings',
				'type'        => 'checkbox',
			) );

		endif;

		// Add Setting
		$wp_customize->add_setting( 'ruki_home_featured_title', array(
			'default'           => '',
			'sanitize_callback' => 'ruki_featured_posts_sanitize_text',
		) );

		// Control Options
		$wp_customize->add_control( 'ruki_home_featured_title', array(
			'label'       => esc_html__( 'Title', 'ruki-featured-posts' ),
			'section'     => 'ruki_home_featured_settings',
			'type'        => 'text',
		) );

		// Add Setting
		$wp_customize->add_setting( 'ruki_home_featured_type', array(
			'default'           => 'recent',
			'sanitize_callback' => 'ruki_sanitize_post_type',
		) );

		// Control Options
		$wp_customize->add_control( 'ruki_home_featured_type', array(
			'label'       => esc_html__( 'Post Type', 'ruki-featured-posts' ),
			'section'     => 'ruki_home_featured_settings',
			'type'        => 'radio',
			'choices'     => array(
				'recent' => esc_html__( 'Recent Posts', 'ruki-featured-posts' ),
				'popular' => esc_html__( 'Popular Posts', 'ruki-featured-posts' ),
				'post_ids' => esc_html__( 'Specific Posts (Enter post IDs below)', 'ruki-featured-posts' ),
				'random' => esc_html__( 'Random Posts', 'ruki-featured-posts' ),
			),
		) );

		// Post Ids
		$wp_customize->add_setting( 'ruki_home_featured_post_ids', array(
			'default'           => '',
			'sanitize_callback' => 'ruki_featured_posts_sanitize_text',
		) );

		// Post IDs
		$wp_customize->add_control( 'ruki_home_featured_post_ids', array(
			'label'       => esc_html__( 'Post IDs', 'ruki-featured-posts' ),
			'description' => esc_html__( 'Enter a comma separated List of post IDs', 'ruki-featured-posts' ),
			'section'     => 'ruki_home_featured_settings',
			'type'        => 'text',
		) );

		// Tag Ids
		$wp_customize->add_setting( 'ruki_home_featured_tag_ids', array(
			'default'           => '',
			'sanitize_callback' => 'ruki_featured_posts_sanitize_text',
		) );

		// Tag IDs
		$wp_customize->add_control( 'ruki_home_featured_tag_ids', array(
			'label'       => esc_html__( 'Tag IDs', 'ruki-featured-posts' ),
			'description' => esc_html__( 'Enter a comma separated List of Tag IDs', 'ruki-featured-posts' ),
			'section'     => 'ruki_home_featured_settings',
			'type'        => 'text',
		) );

		// Add Setting
		$wp_customize->add_setting( 'ruki_home_featured_post_cat', array(
			'default'           => '',
			'sanitize_callback' => 'absint',
		) );

		// Control Options
		$wp_customize->add_control( 'ruki_home_featured_post_cat', array(
			'label'       => esc_html__( 'Category', 'ruki-featured-posts' ),
			'section'     => 'ruki_home_featured_settings',
			'description' => esc_html__( 'Can be used in combination with post type', 'ruki-featured-posts' ),
			'type'        => 'select',
			'choices'     => ruki_get_blog_categories(),
		) );

		// Add Setting
		$wp_customize->add_setting( 'ruki_home_featured_post_format', array(
			'default'           => '',
			'sanitize_callback' => 'ruki_sanitize_post_format',
		) );

		// Control Options
		$wp_customize->add_control( 'ruki_home_featured_post_format', array(
			'label'       => esc_html__( 'Post Format', 'ruki-featured-posts' ),
			'section'     => 'ruki_home_featured_settings',
			'type'        => 'select',
			'choices'     => array(
				'' => esc_html__( 'Any', 'ruki-featured-posts' ),
				'post-format-standard' => esc_html__( 'Standard', 'ruki-featured-posts' ),
				'post-format-video' => esc_html__( 'Video', 'ruki-featured-posts' ),
				'post-format-audio' => esc_html__( 'Audio', 'ruki-featured-posts' ),
				'post-format-image' => esc_html__( 'Image', 'ruki-featured-posts' ),
				'post-format-gallery' => esc_html__( 'Gallery', 'ruki-featured-posts' ),
			),
		) );

		/**
		 * Number of Posts
		 */
		$wp_customize->add_setting( 'ruki_home_featured_num', array(
			'default'           => 3,
			'sanitize_callback' => 'absint',
		) );

		$wp_customize->add_control( 'ruki_home_featured_num', array(
			'label'       => esc_html__( 'Number of posts', 'ruki-featured-posts' ),
			'section'     => 'ruki_home_featured_settings',
			'type'        => 'number',
			'input_attrs' => array(
		        'min'   => 1,
		        'max'   => apply_filters( 'ruki_featured_posts_max_posts', 999 ),
		    ),
		) );

		/**
		 * Number of Columns
		 */
		$wp_customize->add_setting( 'ruki_home_featured_cols', array(
			'default'           => 3,
			'sanitize_callback' => 'absint',
		) );

		if ( apply_filters( 'ruki_featured_posts_theme_supports_carousel', false )) :

			$wp_customize->add_control( 'ruki_home_featured_cols', array(
				'label'       => esc_html__( 'Number of columns/slides', 'ruki-featured-posts' ),
				'section'     => 'ruki_home_featured_settings',
				'type'        => 'number',
				'input_attrs' => array(
			        'min'   => 1,
			        'max'   => apply_filters( 'ruki_featured_posts_max_cols', 3 ),
			    ),
			) );

		else:

			$wp_customize->add_control( 'ruki_home_featured_cols', array(
				'label'       => esc_html__( 'Number of columns', 'ruki-featured-posts' ),
				'section'     => 'ruki_home_featured_settings',
				'type'        => 'number',
				'input_attrs' => array(
			        'min'   => 1,
			        'max'   => apply_filters( 'ruki_featured_posts_max_cols', 3 ),
			    ),
			) );

		endif;

		/**
		 * Offset
		 */
		$wp_customize->add_setting( 'ruki_home_featured_offset', array(
			'default'           => '0',
			'sanitize_callback' => 'absint',
		) );

		$wp_customize->add_control( 'ruki_home_featured_offset', array(
			'label'       => esc_html__( 'Offset (Number of posts to skip)', 'ruki-featured-posts' ),
			'section'     => 'ruki_home_featured_settings',
			'type'        => 'number',
			'input_attrs' => array(
		        'min'   => 0,
		    ),
		) );

		// Exclude Post Ids
		$wp_customize->add_setting( 'ruki_home_featured_exclude_post_ids', array(
			'default'           => '',
			'sanitize_callback' => 'ruki_featured_posts_sanitize_text',
		) );

		// Post IDs
		$wp_customize->add_control( 'ruki_home_featured_exclude_post_ids', array(
			'label'       => esc_html__( 'Exclude Post IDs', 'ruki-featured-posts' ),
			'description' => esc_html__( 'Enter a comma separated List of post IDs to Exclude', 'ruki-featured-posts' ),
			'section'     => 'ruki_home_featured_settings',
			'type'        => 'text',
		) );

		if ( apply_filters( 'ruki_featured_posts_theme_supports_carousel', false ) ):

			/**
			 * Layout
			 */
			$wp_customize->add_setting( 'ruki_home_featured_layout', array(
				'default'           => 'grid',
				'sanitize_callback' => 'ruki_sanitize_featured_posts_layout',
			) );

			$wp_customize->add_control( 'ruki_home_featured_layout', array(
				'label'       => esc_html__( 'Layout', 'ruki-featured-posts' ),
				'section'     => 'ruki_home_featured_settings',
				'type'        => 'select',
				'choices'     => array(
					'grid' => esc_html__( 'Grid', 'ruki-featured-posts' ),
					'carousel' => esc_html__( 'Carousel', 'ruki-featured-posts' ),
				),
			) );

		endif;

		/**
		 * Loop style
		 */
		$wp_customize->add_setting( 'ruki_home_featured_loop_style', array(
			'default'           => 'default',
			'sanitize_callback' => 'ruki_sanitize_loop_style',
		) );

		$wp_customize->add_control( 'ruki_home_featured_loop_style', array(
			'label'       => esc_html__( 'Post Style', 'ruki-featured-posts' ),
			'section'     => 'ruki_home_featured_settings',
			'type'        => 'select',
			'choices'     => array(
				'default' => esc_html__( 'Default', 'ruki-featured-posts' ),
				'cover' => esc_html__( 'Cover', 'ruki-featured-posts' ), // Remove this with a filter if not required for a theme
			),
		) );

		$wp_customize->add_setting( 'ruki_home_featured_image_size', array(
			'default'           => 'landscape',
			'sanitize_callback' => 'ruki_sanitize_aspect_ratio',
		) );

		$wp_customize->add_control( 'ruki_home_featured_image_size', array(
			'label'       => esc_html__( 'Thumbnail Size', 'ruki-featured-posts' ),
			'section'     => 'ruki_home_featured_settings',
			'type'        => 'select',
			'choices'     => array(
				'landscape' => esc_html__( 'Landscape', 'ruki-featured-posts' ),
				'portrait' => esc_html__( 'Portrait', 'ruki-featured-posts' ),
				'square' => esc_html__( 'Square', 'ruki-featured-posts' ),
		),
		) );

		$wp_customize->add_setting( 'ruki_home_featured_arrows', array(
			'default'           => true,
			'sanitize_callback' => 'ruki_featured_posts_sanitize_checkbox',
		) );

		$wp_customize->add_control( 'ruki_home_featured_arrows', array(
			'label'       => esc_html__( 'Show Prev/Next Arrows', 'ruki-featured-posts' ),
			'section'     => 'ruki_home_featured_settings',
			'type'        => 'checkbox',
		) );

		$wp_customize->add_setting( 'ruki_home_featured_thumbnail', array(
			'default'           => true,
			'sanitize_callback' => 'ruki_featured_posts_sanitize_checkbox',
		) );

		$wp_customize->add_control( 'ruki_home_featured_thumbnail', array(
			'label'       => esc_html__( 'Thumbnail', 'ruki-featured-posts' ),
			'section'     => 'ruki_home_featured_settings',
			'type'        => 'checkbox',
		) );

		$wp_customize->add_setting( 'ruki_home_featured_video', array(
			'default'           => true,
			'sanitize_callback' => 'ruki_featured_posts_sanitize_checkbox',
		) );

		$wp_customize->add_control( 'ruki_home_featured_video', array(
			'label'       => esc_html__( 'Video', 'ruki-featured-posts' ),
			'section'     => 'ruki_home_featured_settings',
			'type'        => 'checkbox',
		) );

		/**
		 * Entry title/meta
		 */

		$wp_customize->add_setting( 'ruki_home_featured_excerpt', array(
			'default'           => false,
			'sanitize_callback' => 'ruki_featured_posts_sanitize_checkbox',
		) );

		$wp_customize->add_control( 'ruki_home_featured_excerpt', array(
			'label'       => esc_html__( 'Excerpt', 'ruki-featured-posts' ),
			'section'     => 'ruki_home_featured_settings',
			'type'        => 'checkbox',
		) );

		$wp_customize->add_setting( 'ruki_home_featured_read_more', array(
			'default'           => false,
			'sanitize_callback' => 'ruki_featured_posts_sanitize_checkbox',
		) );

		$wp_customize->add_control( 'ruki_home_featured_read_more', array(
			'label'       => esc_html__( 'Read More', 'ruki-featured-posts' ),
			'section'     => 'ruki_home_featured_settings',
			'type'        => 'checkbox',
		) );

		// Entry Title
		$wp_customize->add_setting( 'ruki_home_featured_entry_title', array(
			'default'           => true,
			'sanitize_callback' => 'ruki_featured_posts_sanitize_checkbox',
		) );

		$wp_customize->add_control( 'ruki_home_featured_entry_title', array(
			'label'       => esc_html__( 'Entry Title', 'ruki-featured-posts' ),
			'section'     => 'ruki_home_featured_settings',
			'type'        => 'checkbox',
		) );

		// Author Meta
		$wp_customize->add_setting( 'ruki_home_featured_entry_meta_by', array(
			'default'           => true,
			'sanitize_callback' => 'ruki_featured_posts_sanitize_checkbox',
		) );

		$wp_customize->add_control( 'ruki_home_featured_entry_meta_by', array(
			'label'       => esc_html__( '"by"', 'ruki-featured-posts' ),
			'section'     => 'ruki_home_featured_settings',
			'type'        => 'checkbox',
		) );

		// Author Meta
		$wp_customize->add_setting( 'ruki_home_featured_entry_meta_author', array(
			'default'           => true,
			'sanitize_callback' => 'ruki_featured_posts_sanitize_checkbox',
		) );

		$wp_customize->add_control( 'ruki_home_featured_entry_meta_author', array(
			'label'       => esc_html__( 'Author', 'ruki-featured-posts' ),
			'section'     => 'ruki_home_featured_settings',
			'type'        => 'checkbox',
		) );

		// Author Avatar
		$wp_customize->add_setting( 'ruki_home_featured_entry_meta_author_avatar', array(
			'default'           => false,
			'sanitize_callback' => 'ruki_featured_posts_sanitize_checkbox',
		) );

		$wp_customize->add_control( 'ruki_home_featured_entry_meta_author_avatar', array(
			'label'       => esc_html__( 'Author Avatar', 'ruki-featured-posts' ),
			'section'     => 'ruki_home_featured_settings',
			'type'        => 'checkbox',
		) );

		// Category Meta
		$wp_customize->add_setting( 'ruki_home_featured_entry_meta_category', array(
			'default'           => true,
			'sanitize_callback' => 'ruki_featured_posts_sanitize_checkbox',
		) );

		$wp_customize->add_control( 'ruki_home_featured_entry_meta_category', array(
			'label'       => esc_html__( 'Category', 'ruki-featured-posts' ),
			'section'     => 'ruki_home_featured_settings',
			'type'        => 'checkbox',
		) );

		// Date Meta
		$wp_customize->add_setting( 'ruki_home_featured_entry_meta_date', array(
			'default'           => true,
			'sanitize_callback' => 'ruki_featured_posts_sanitize_checkbox',
		) );

		$wp_customize->add_control( 'ruki_home_featured_entry_meta_date', array(
			'label'       => esc_html__( 'Date', 'ruki-featured-posts' ),
			'section'     => 'ruki_home_featured_settings',
			'type'        => 'checkbox',
		) );

		// Date Meta
		if ( function_exists( 'ruki_read_time' ) ) :
			$wp_customize->add_setting( 'ruki_home_featured_entry_meta_read_time', array(
				'default'           => false,
				'sanitize_callback' => 'ruki_featured_posts_sanitize_checkbox',
			) );

			$wp_customize->add_control( 'ruki_home_featured_entry_meta_read_time', array(
				'label'       => esc_html__( 'Read Time', 'ruki-featured-posts' ),
				'section'     => 'ruki_home_featured_settings',
				'type'        => 'checkbox',
			) );
		endif;

		// Comments Meta
		$wp_customize->add_setting( 'ruki_home_featured_entry_meta_comment_count', array(
			'default'           => true,
			'sanitize_callback' => 'ruki_featured_posts_sanitize_checkbox',
		) );

		$wp_customize->add_control( 'ruki_home_featured_entry_meta_comment_count', array(
			'label'       => esc_html__( 'Comment Count', 'ruki-featured-posts' ),
			'section'     => 'ruki_home_featured_settings',
			'type'        => 'checkbox',
		) );

		// Post format icons
		$wp_customize->add_setting( 'ruki_home_featured_post_format_icons', array(
			'default'           => true,
			'sanitize_callback' => 'ruki_featured_posts_sanitize_checkbox',
		) );

		// Control Options
		$wp_customize->add_control( 'ruki_home_featured_post_format_icons', array(
			'label'       => esc_html__( 'Show Post Format Icons', 'ruki-featured-posts' ),
			'section'     => 'ruki_home_featured_settings',
			'type'        => 'checkbox',
		) );

		// Added in version 1.4

		if ( apply_filters( 'ruki_home_featured_background', false ) ) :

			$wp_customize->add_setting( 'ruki_home_featured_background', array(
				'default'           => '',
				'transport' => 'refresh',
				'sanitize_callback' => 'sanitize_hex_color',
			) );

			// Control Options
			$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'ruki_home_featured_background', array(
		      'section' => 'ruki_home_featured_settings',
		      'label'   => esc_html__( 'Background Color', 'ruki-featured-posts' ),
		    ) ) );

		    $wp_customize->add_setting( 'ruki_home_featured_title_color', array(
				'default'           => '',
				'transport' => 'refresh',
				'sanitize_callback' => 'sanitize_hex_color',
			) );

			// Control Options
			$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'ruki_home_featured_title_color', array(
		      'section' => 'ruki_home_featured_settings',
		      'label'   => esc_html__( 'Title Color', 'ruki-featured-posts' ),
		    ) ) );

		    if ( apply_filters( 'ruki_featured_posts_supports_card', false ) ) :

			    $wp_customize->add_setting( 'ruki_home_featured_card_background', array(
					'default'           => '',
					'transport' => 'refresh',
					'sanitize_callback' => 'sanitize_hex_color',
				) );

				// Control Options
				$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'ruki_home_featured_card_background', array(
			      'section' => 'ruki_home_featured_settings',
			      'label'   => esc_html__( 'Post Background Color', 'ruki-featured-posts' ),
			    ) ) );

			endif;

		    $wp_customize->add_setting( 'ruki_home_featured_entry_title_link_color', array(
				'default'           => '',
				'transport' => 'refresh',
				'sanitize_callback' => 'sanitize_hex_color',
			) );

			// Control Options
			$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'ruki_home_featured_entry_title_link_color', array(
		      'section' => 'ruki_home_featured_settings',
		      'label'   => esc_html__( 'Entry Title Link Color', 'ruki-featured-posts' ),
		    ) ) );

		    $wp_customize->add_setting( 'ruki_home_featured_entry_meta_color', array(
				'default'           => '',
				'transport' => 'refresh',
				'sanitize_callback' => 'sanitize_hex_color',
			) );

			// Control Options
			$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'ruki_home_featured_entry_meta_color', array(
		      'section' => 'ruki_home_featured_settings',
		      'label'   => esc_html__( 'Entry Meta Color', 'ruki-featured-posts' ),
		    ) ) );

		    $wp_customize->add_setting( 'ruki_home_featured_entry_meta_link_color', array(
				'default'           => '',
				'transport' => 'refresh',
				'sanitize_callback' => 'sanitize_hex_color',
			) );

			// Control Options
			$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'ruki_home_featured_entry_meta_link_color', array(
		      'section' => 'ruki_home_featured_settings',
		      'label'   => esc_html__( 'Entry Meta Link Color', 'ruki-featured-posts' ),
		    ) ) );

		    $wp_customize->add_setting( 'ruki_home_featured_entry_content_color', array(
				'default'           => '',
				'transport' => 'refresh',
				'sanitize_callback' => 'sanitize_hex_color',
			) );

			// Control Options
			$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'ruki_home_featured_entry_content_color', array(
		      'section' => 'ruki_home_featured_settings',
		      'label'   => esc_html__( 'Excerpt Color', 'ruki-featured-posts' ),
		    ) ) );

		     $wp_customize->add_setting( 'ruki_home_featured_continue_reading_color', array(
				'default'           => '',
				'transport' => 'refresh',
				'sanitize_callback' => 'sanitize_hex_color',
			) );

			// Control Options
			$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'ruki_home_featured_continue_reading_color', array(
		      'section' => 'ruki_home_featured_settings',
		      'label'   => esc_html__( 'Continue Reading Color', 'ruki-featured-posts' ),
		    ) ) );

		     $wp_customize->add_setting( 'ruki_home_featured_arrows_background', array(
				'default'           => '',
				'transport' => 'refresh',
				'sanitize_callback' => 'sanitize_hex_color',
			) );

			// Control Options
			$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'ruki_home_featured_arrows_background', array(
		      'section' => 'ruki_home_featured_settings',
		      'label'   => esc_html__( 'Prev/Next Arrows Background', 'ruki-featured-posts' ),
		    ) ) );

		    $wp_customize->add_setting( 'ruki_home_featured_arrows_color', array(
				'default'           => '',
				'transport' => 'refresh',
				'sanitize_callback' => 'sanitize_hex_color',
			) );

			// Control Options
			$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'ruki_home_featured_arrows_color', array(
		      'section' => 'ruki_home_featured_settings',
		      'label'   => esc_html__( 'Prev/Next Arrows Color', 'ruki-featured-posts' ),
		    ) ) );

		endif;

		// ========================================================
		// Custom posts
		// ========================================================

		/**
		 * This is a custom posts loop, that requires activation
		 * within each theme as required.
		 * To activate: ONLY add_action is required add_filter is optional
		 =================
		   function filter_ruki_custom_posts_hook() {
				return 'user_defined_hook';
			}
			add_filter( 'ruki_custom_posts_hook', 'filter_ruki_custom_posts_hook' );
			add_action( apply_filters( 'ruki_custom_posts_hook', 'ruki_before_footer' ), 'ruki_custom_posts' );
		 =================
		 */

		if ( apply_filters( 'ruki_custom_posts', false ) ) {

			$wp_customize->add_section( 'ruki_custom_posts_settings', array(
			'title'    => apply_filters( 'ruki_custom_posts_section_name', 'Custom Posts' ),
			'panel'    => 'ruki_featured_posts',
			'priority' => 160,
		) );

		/**
		 * Display Related Posts
		 */
		$wp_customize->add_setting( 'ruki_custom_posts', array(
			'default'           => false,
			'sanitize_callback' => 'ruki_featured_posts_sanitize_checkbox',
		) );

		$wp_customize->add_control( 'ruki_custom_posts', array(
			'label'       => esc_html__( 'Display Custom Posts', 'ruki-featured-posts' ),
			'section'     => 'ruki_custom_posts_settings',
			'type'        => 'checkbox',
		) );

		// Add Setting
		$wp_customize->add_setting( 'ruki_custom_posts_title', array(
			'default'           => '',
			'sanitize_callback' => 'ruki_featured_posts_sanitize_text',
		) );

		// Control Options
		$wp_customize->add_control( 'ruki_custom_posts_title', array(
			'label'       => esc_html__( 'Title', 'ruki-featured-posts' ),
			'section'     => 'ruki_custom_posts_settings',
			'type'        => 'text',
		) );

		// Add Setting
		$wp_customize->add_setting( 'ruki_custom_posts_type', array(
			'default'           => 'recent',
			'sanitize_callback' => 'ruki_sanitize_post_type',
		) );

		// Control Options
		$wp_customize->add_control( 'ruki_custom_posts_type', array(
			'label'       => esc_html__( 'Post Type', 'ruki-featured-posts' ),
			'section'     => 'ruki_custom_posts_settings',
			'type'        => 'radio',
			'choices'     => array(
				'recent' => esc_html__( 'Recent Posts', 'ruki-featured-posts' ),
				'popular' => esc_html__( 'Popular Posts', 'ruki-featured-posts' ),
				'post_ids' => esc_html__( 'Specific Posts (Enter post IDs below)', 'ruki-featured-posts' ),
				'random' => esc_html__( 'Random Posts', 'ruki-featured-posts' ),
			),
		) );

		// Post Ids
		$wp_customize->add_setting( 'ruki_custom_posts_post_ids', array(
			'default'           => '',
			'sanitize_callback' => 'ruki_featured_posts_sanitize_text',
		) );

		// Post IDs
		$wp_customize->add_control( 'ruki_custom_posts_post_ids', array(
			'label'       => esc_html__( 'Post IDs', 'ruki-featured-posts' ),
			'description' => esc_html__( 'Enter a comma separated List of post IDs', 'ruki-featured-posts' ),
			'section'     => 'ruki_custom_posts_settings',
			'type'        => 'text',
		) );

		// Add Setting
		$wp_customize->add_setting( 'ruki_custom_posts_post_cat', array(
			'default'           => '',
			'sanitize_callback' => 'absint',
		) );

		// Control Options
		$wp_customize->add_control( 'ruki_custom_posts_post_cat', array(
			'label'       => esc_html__( 'Category', 'ruki-featured-posts' ),
			'section'     => 'ruki_custom_posts_settings',
			'description' => esc_html__( 'Can be used in combination with post type', 'ruki-featured-posts' ),
			'type'        => 'select',
			'choices'     => ruki_get_blog_categories(),
		) );

		/**
		 * Number of Posts
		 */
		$wp_customize->add_setting( 'ruki_custom_posts_num', array(
			'default'           => 3,
			'sanitize_callback' => 'absint',
		) );

		$wp_customize->add_control( 'ruki_custom_posts_num', array(
			'label'       => esc_html__( 'Number of posts', 'ruki-featured-posts' ),
			'section'     => 'ruki_custom_posts_settings',
			'type'        => 'number',
			'input_attrs' => array(
		        'min'   => 1,
		        'max'   => apply_filters( 'ruki_featured_posts_max_posts', 999 ),
		    ),
		) );

		/**
		 * Number of Columns
		 */
		$wp_customize->add_setting( 'ruki_custom_posts_cols', array(
			'default'           => 3,
			'sanitize_callback' => 'absint',
		) );

		$wp_customize->add_control( 'ruki_custom_posts_cols', array(
			'label'       => esc_html__( 'Number of columns', 'ruki-featured-posts' ),
			'section'     => 'ruki_custom_posts_settings',
			'type'        => 'number',
			'input_attrs' => array(
		        'min'   => 1,
		        'max'   => apply_filters( 'ruki_featured_posts_max_cols', 3 ),
		    ),
		) );

		/**
		 * Offset
		 */
		$wp_customize->add_setting( 'ruki_custom_posts_offset', array(
			'default'           => '0',
			'sanitize_callback' => 'absint',
		) );

		$wp_customize->add_control( 'ruki_custom_posts_offset', array(
			'label'       => esc_html__( 'Offset (Number of posts to skip)', 'ruki-featured-posts' ),
			'section'     => 'ruki_custom_posts_settings',
			'type'        => 'number',
			'input_attrs' => array(
		        'min'   => 0,
		    ),
		) );

		/**
		 * Loop style
		 */
		$wp_customize->add_setting( 'ruki_custom_posts_loop_style', array(
			'default'           => 'default',
			'sanitize_callback' => 'ruki_sanitize_loop_style',
		) );

		$wp_customize->add_control( 'ruki_custom_posts_loop_style', array(
			'label'       => esc_html__( 'Post Style', 'ruki-featured-posts' ),
			'section'     => 'ruki_custom_posts_settings',
			'type'        => 'select',
			'choices'     => array(
				'default' => esc_html__( 'Default', 'ruki-featured-posts' ),
				'cover' => esc_html__( 'Cover', 'ruki-featured-posts' ), // Remove this with a filter if not required for a theme
			),
		) );

		$wp_customize->add_setting( 'ruki_custom_posts_image_size', array(
			'default'           => 'landscape',
			'sanitize_callback' => 'ruki_sanitize_aspect_ratio',
		) );

		$wp_customize->add_control( 'ruki_custom_posts_image_size', array(
			'label'       => esc_html__( 'Thumbnail Size', 'ruki-featured-posts' ),
			'section'     => 'ruki_custom_posts_settings',
			'type'        => 'select',
			'choices'     => array(
				'landscape' => esc_html__( 'Landscape', 'ruki-featured-posts' ),
				'portrait' => esc_html__( 'Portrait', 'ruki-featured-posts' ),
				'square' => esc_html__( 'Square', 'ruki-featured-posts' ),
		),
		) );

		/**
		 * Entry title/meta
		 */

		$wp_customize->add_setting( 'ruki_custom_posts_excerpt', array(
			'default'           => false,
			'sanitize_callback' => 'ruki_featured_posts_sanitize_checkbox',
		) );

		$wp_customize->add_control( 'ruki_custom_posts_excerpt', array(
			'label'       => esc_html__( 'Excerpt', 'ruki-featured-posts' ),
			'section'     => 'ruki_custom_posts_settings',
			'type'        => 'checkbox',
		) );

		// Entry Title
		$wp_customize->add_setting( 'ruki_custom_posts_entry_title', array(
			'default'           => true,
			'sanitize_callback' => 'ruki_featured_posts_sanitize_checkbox',
		) );

		$wp_customize->add_control( 'ruki_custom_posts_entry_title', array(
			'label'       => esc_html__( 'Entry Title', 'ruki-featured-posts' ),
			'section'     => 'ruki_custom_posts_settings',
			'type'        => 'checkbox',
		) );

		// Author Meta
		$wp_customize->add_setting( 'ruki_custom_posts_entry_meta_author', array(
			'default'           => true,
			'sanitize_callback' => 'ruki_featured_posts_sanitize_checkbox',
		) );

		$wp_customize->add_control( 'ruki_custom_posts_entry_meta_author', array(
			'label'       => esc_html__( 'Author', 'ruki-featured-posts' ),
			'section'     => 'ruki_custom_posts_settings',
			'type'        => 'checkbox',
		) );

		// Author Avatar
		$wp_customize->add_setting( 'ruki_custom_posts_entry_meta_author_avatar', array(
			'default'           => false,
			'sanitize_callback' => 'ruki_featured_posts_sanitize_checkbox',
		) );

		$wp_customize->add_control( 'ruki_custom_posts_entry_meta_author_avatar', array(
			'label'       => esc_html__( 'Author Avatar', 'ruki-featured-posts' ),
			'section'     => 'ruki_custom_posts_settings',
			'type'        => 'checkbox',
		) );

		// Category Meta
		$wp_customize->add_setting( 'ruki_custom_posts_entry_meta_category', array(
			'default'           => true,
			'sanitize_callback' => 'ruki_featured_posts_sanitize_checkbox',
		) );

		$wp_customize->add_control( 'ruki_custom_posts_entry_meta_category', array(
			'label'       => esc_html__( 'Category', 'ruki-featured-posts' ),
			'section'     => 'ruki_custom_posts_settings',
			'type'        => 'checkbox',
		) );

		// Date Meta
		$wp_customize->add_setting( 'ruki_custom_posts_entry_meta_date', array(
			'default'           => true,
			'sanitize_callback' => 'ruki_featured_posts_sanitize_checkbox',
		) );

		$wp_customize->add_control( 'ruki_custom_posts_entry_meta_date', array(
			'label'       => esc_html__( 'Date', 'ruki-featured-posts' ),
			'section'     => 'ruki_custom_posts_settings',
			'type'        => 'checkbox',
		) );

		// Date Meta
		if ( function_exists( 'ruki_read_time' ) ) :
			$wp_customize->add_setting( 'ruki_custom_posts_entry_meta_read_time', array(
				'default'           => false,
				'sanitize_callback' => 'ruki_featured_posts_sanitize_checkbox',
			) );

			$wp_customize->add_control( 'ruki_custom_posts_entry_meta_read_time', array(
				'label'       => esc_html__( 'Read Time', 'ruki-featured-posts' ),
				'section'     => 'ruki_custom_posts_settings',
				'type'        => 'checkbox',
			) );
		endif;

		// Comments Meta
		$wp_customize->add_setting( 'ruki_custom_posts_entry_meta_comment_count', array(
			'default'           => true,
			'sanitize_callback' => 'ruki_featured_posts_sanitize_checkbox',
		) );

		$wp_customize->add_control( 'ruki_custom_posts_entry_meta_comment_count', array(
			'label'       => esc_html__( 'Comment Count', 'ruki-featured-posts' ),
			'section'     => 'ruki_custom_posts_settings',
			'type'        => 'checkbox',
		) );

		// Post format icons
		$wp_customize->add_setting( 'ruki_custom_posts_post_format_icons', array(
			'default'           => true,
			'sanitize_callback' => 'ruki_featured_posts_sanitize_checkbox',
		) );

		// Control Options
		$wp_customize->add_control( 'ruki_custom_posts_post_format_icons', array(
			'label'       => esc_html__( 'Show Post Format Icons', 'ruki-featured-posts' ),
			'section'     => 'ruki_custom_posts_settings',
			'type'        => 'checkbox',
		) );

		} // End if custom posts

}

add_action( 'customize_register', 'ruki_featured_posts_customize_register', 100 );

// ========================================================
// Sanitize checkbox
// ========================================================

if ( ! function_exists( 'ruki_featured_posts_sanitize_checkbox' ) ) {

	function ruki_featured_posts_sanitize_checkbox( $input ) {

			return ( $input === true ) ? true : false;

	}

}

// ========================================================
// Sanitize text field
// ========================================================

if ( ! function_exists( 'ruki_featured_posts_sanitize_text' ) ) {

	function ruki_featured_posts_sanitize_text( $text ) {
	    return sanitize_text_field( $text );
	}

}

// ========================================================
// Sanitize Post Type
// ========================================================

if ( ! function_exists( 'ruki_sanitize_post_type' ) ) {

	function ruki_sanitize_post_type( $input ) {
		$valid = array(
			'recent' => esc_html__( 'Recent Posts', 'ruki-featured-posts' ),
			'popular' => esc_html__( 'Popular Posts', 'threforty' ),
			'post_ids' => esc_html__( 'Specific Posts (Enter post IDs below)', 'ruki-featured-posts' ),
			'random' => esc_html__( 'Random Posts', 'ruki-featured-posts' ),
		);

		if ( array_key_exists( $input, $valid ) ) {
			return $input;
		}

		return '';
	}

}

// ========================================================
// Sanitize Post Format
// ========================================================

if ( ! function_exists( 'ruki_sanitize_post_format' ) ) {

	function ruki_sanitize_post_format( $input ) {
		$valid = array(
			'' => esc_html__( 'Any', 'ruki-featured-posts' ),
			'post-format-standard' => esc_html__( 'Standard', 'ruki-featured-posts' ),
			'post-format-video' => esc_html__( 'Video', 'ruki-featured-posts' ),
			'post-format-audio' => esc_html__( 'Audio', 'ruki-featured-posts' ),
			'post-format-image' => esc_html__( 'Image', 'ruki-featured-posts' ),
			'post-format-gallery' => esc_html__( 'Gallery', 'ruki-featured-posts' ),
		);

		if ( array_key_exists( $input, $valid ) ) {
			return $input;
		}

		return '';
	}

}

// ========================================================
// Sanitize Post Loop
// ========================================================
if ( ! function_exists( 'ruki_sanitize_featured_posts_layout' ) ) {

function ruki_sanitize_featured_posts_layout( $input ) {
	$valid = array(
		'grid' => esc_html__( 'Grid', 'ruki-featured-posts' ),
		'carousel' => esc_html__( 'Carousel', 'ruki-featured-posts' ),
	);

	if ( array_key_exists( $input, $valid ) ) {
		return $input;
	}

	return '';
}

}

// ========================================================
// Sanitize Post Loop
// ========================================================
if ( ! function_exists( 'ruki_sanitize_loop_style' ) ) {

function ruki_sanitize_loop_style( $input ) {
	$valid = array(
		'default' => esc_html__( 'Default', 'ruki-featured-posts' ),
		'cover' => esc_html__( 'Cover', 'ruki-featured-posts' ),
	);

	if ( array_key_exists( $input, $valid ) ) {
		return $input;
	}

	return '';
}

}

// ========================================================
// Sanitize thumbnail aspect ratio
// ========================================================
if ( ! function_exists( 'ruki_sanitize_aspect_ratio' ) ) {

function ruki_sanitize_aspect_ratio( $input ) {
	$valid = array(
		'landscape' => esc_html__( 'Landscape', 'ruki-featured-posts' ),
		'portrait' => esc_html__( 'Portrait', 'ruki-featured-posts' ),
		'square' => esc_html__( 'Square', 'ruki-featured-posts' ),
		'uncropped' => esc_html__( 'Uncropped', 'ruki-featured-posts' ),
	);

	if ( array_key_exists( $input, $valid ) ) {
		return $input;
	}

	return '';
}

}

// ========================================================
// Create an Array of categories
// ========================================================

if ( ! function_exists( 'ruki_get_blog_categories' ) ) {

	function ruki_get_blog_categories() {

		$categories = get_categories('type=post');

		$cats = array('' => '');

		foreach( $categories as $category ) {
		    $cats[$category->term_id] = $category->name;
		}

		return $cats;
	}

}


// ========================================================
// Create an Array of Image Sizes (Names)
// ========================================================

if ( ! function_exists( 'ruki_get_registered_image_sizes' ) ) {

	function ruki_get_registered_image_sizes() {

		global $_wp_additional_image_sizes;

		// Core WP image sizes
		$id = array(
			'thumbnail' => esc_html__( 'Thumbnail', 'ruki-featured-posts' ),
			'medium' => esc_html__( 'Medium', 'ruki-featured-posts' ),
			'medium_large' => esc_html__( 'Medium Large', 'ruki-featured-posts' ),
			'large' => esc_html__( 'Large', 'ruki-featured-posts' ));

		foreach ($_wp_additional_image_sizes as $key => $value) {

			$name = ucwords(str_replace('-', ' ', $key));
			$id[$key] = $name;

			}

		return $id;

	}

}


?>