<?php

/**
Plugin Name: Ruki: Featured Posts
Plugin URI:  http://www.3forty.media
Description: Promote your favourite posts with this configurable featured posts display plugin
Version:     1.3
Author:      3FortyMedia
Author URI:  http://www.3forty.media
Text Domain: ruki-featured-posts
Domain Path: /languages/
License: GNU General Public License v2 or later
License URI: http://www.gnu.org/licenses/gpl-2.0.html
*/

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

function ruki_featured_posts_init() {
	// load language files.
	load_plugin_textdomain( 'ruki-featured-posts', false, dirname( plugin_basename( __FILE__ ) ) . '/languages' );
}
add_action( 'init', 'ruki_featured_posts_init' );

define( 'RUKI_FEATURED_POSTS__PLUGIN_DIR', plugin_dir_path( __FILE__ ) );

global $post_ids;

// Include customizer settings
include( RUKI_FEATURED_POSTS__PLUGIN_DIR . 'inc/customizer.php' );

// Category after header
function ruki_category_featured( ) {

		if ( locate_template( 'template-parts/ruki-plugin-parts/featured-posts/category-featured.php', false ) ) {
			locate_template( 'template-parts/ruki-plugin-parts/featured-posts/category-featured.php', true);
		} else {
			include( RUKI_FEATURED_POSTS__PLUGIN_DIR . 'plugin-parts/category-featured.php' );
		}

}
add_action('ruki_after_header', 'ruki_category_featured', 10 );

// Home after header (after hero)
function ruki_home_featured( ) {

		if ( locate_template( 'template-parts/ruki-plugin-parts/featured-posts/home-featured.php', false ) ) {
			locate_template( 'template-parts/ruki-plugin-parts/featured-posts/home-featured.php', true);
		} else {
			include( RUKI_FEATURED_POSTS__PLUGIN_DIR . 'plugin-parts/home-featured.php' );
		}

}
add_action('ruki_after_header', 'ruki_home_featured', 30 );

/**
* Custom Posts
* This function requires activation within the theme
*/
function ruki_custom_posts() {

	if ( locate_template( 'template-parts/ruki-plugin-parts/featured-posts/custom-posts.php', false ) ) {
			locate_template( 'template-parts/ruki-plugin-parts/featured-posts/custom-posts.php', true);
		} else {
			include( RUKI_FEATURED_POSTS__PLUGIN_DIR . 'plugin-parts/custom-posts.php' );
		}

}

// ========================================================
// Enqueue slick assets
// ========================================================

function ruki_featured_posts_scripts( ) {

	$category = get_queried_object();

	// Carousel active var
	$carousel_active = ( apply_filters( 'ruki_featured_posts_theme_supports_carousel', false ) && ( ( is_front_page() && ! is_paged() && get_theme_mod( 'ruki_home_featured_layout', 'grid' ) === 'carousel' ) || ( is_category() && get_theme_mod( 'ruki_category_featured_layout', 'grid' ) === 'carousel' && get_transient( 'ruki_category_' . $category->term_id . '_featured' ) ) ) ? true : false );

	/* Enqueue slick assets
	 *
	 * $carousel_active = true
	 * More than 1 post
	 * Featured display is enabled
	 * Theme includes slick inline JS (If Carousel is enabled wihtin theme slick JS file must be included with the theme, plugin only loads slick core)
	 */
	if ( ( is_front_page() && ! is_paged() && get_theme_mod( 'ruki_home_featured_post_num', 3 ) > 1 && get_theme_mod( 'ruki_home_featured', true ) ) || ( is_category() && get_theme_mod( 'ruki_category_featured_post_num', 3 ) > 1 && get_theme_mod( 'ruki_category_featured', true ) ) && $carousel_active && wp_script_is( 'slick-inline', 'enqueued' ) ) {
		wp_enqueue_style('slick', plugin_dir_url( __FILE__ ) . 'slick/slick.css', array(), '1.0.0', 'all');
		wp_enqueue_script( 'slick', plugin_dir_url( __FILE__ ) . 'slick/slick.min.js', array( 'jquery' ), '1.0.0', true);
	}

}
add_action( 'wp_enqueue_scripts', 'ruki_featured_posts_scripts', 200 );

// ========================================================
// Add class to body tag
// ========================================================

function ruki_featured_posts_class( $classes ) {

	$category = get_queried_object();

	if ( is_home() && get_theme_mod( 'ruki_home_featured', true ) ) {
		$classes[] = 'has-featured-posts';
	}
	if ( is_home() && ! is_paged() && get_theme_mod( 'ruki_home_featured', true ) && '' !== get_theme_mod( 'ruki_home_featured_background', '' ) ) {
		$classes[] = 'has-featured-posts-background';
	}
	if ( is_category() && get_theme_mod( 'ruki_category_featured', true ) && get_transient( 'ruki_category_' . $category->term_id . '_featured' ) ) {
		$classes[] = 'has-category-featured';
	}
	if ( is_category() && get_theme_mod( 'ruki_category_featured', true ) && '' !== get_theme_mod( 'ruki_category_featured_background', '' ) && get_transient( 'ruki_category_' . $category->term_id . '_featured' ) ) {
		$classes[] = 'has-category-featured-background';
	}
	if ( get_theme_mod( 'ruki_custom_posts', false ) ) {
		$classes[] = 'has-custom-posts';
	}
	return $classes;
}
add_filter( 'body_class', 'ruki_featured_posts_class' );

// ========================================================
// Admin function Add Featured Post META Box
// ========================================================

function ruki_featured_post_meta() {

	add_meta_box(
		'ruki_featured_post_meta_box',
		esc_html__( 'Ruki  Featured Post', 'ruki-featured-posts' ),
		'ruki_featured_post_callback',
		'post',
		'side',
		'low'
		);

}

add_action( 'add_meta_boxes', 'ruki_featured_post_meta' );

// Callback
function ruki_featured_post_callback( $post ) {

	wp_nonce_field(basename( __FILE__ ), 'ruki_featured_post_meta_nonce' );

		$value = get_post_meta( $post->ID, 'ruki_featured_post', true );

		echo '<p class="howto">Featured posts are used in archive (category) custom post displays</p>';

		echo '<label for="ruki_featured_post">';
		if ($value == '') {
			echo ' <input id="ruki_featured_post" name="ruki_featured_post" type="checkbox" class="checkbox">';
		} else {
			echo ' <input id="ruki_featured_post" name="ruki_featured_post" type="checkbox" class="checkbox" checked="checked">';
		}
		echo esc_html__( 'Featured Post', 'ruki-featured-posts' );
		echo '</label>';

}

// Save
function ruki_save_featured_post_data( $post_id ) {

	// Return if meta-box doesnt exist
	if ( ! isset( $_POST['ruki_featured_post_meta_nonce'] ) ) {
		return;
	}
	// Return if nonce is not valid
	if ( ! wp_verify_nonce( $_POST['ruki_featured_post_meta_nonce'], basename( __FILE__ ))) {
		return;
	}
	// Return if doing and autosave
	if ( defined( 'DOING_AUTOAVE' ) && DOING_AUTOSAVE ) {
		return;
	}

	// Return if user does not have permisson
	if ( ! current_user_can( 'edit_post', $post_id )) {
		return;
	}

	$featured_checkbox = '';

	if (isset($_POST['ruki_featured_post']))
    {
        $featured_checkbox = 1;
    } 

	update_post_meta( $post_id, 'ruki_featured_post', $featured_checkbox );
}

add_action( 'save_post', 'ruki_save_featured_post_data' );

// ========================================================
// Set category featured transient (add_action hooks)
// ========================================================

function ruki_category_featured_set_transient( ) {

	if ( get_theme_mod( 'ruki_category_featured', true ) ) {

		$categories = get_categories('type=post');

		foreach( $categories as $category ) {
		    
		    // Run the query

		    $query_args = array(
			    'post_type'      => 'post',
			    'posts_per_page' => get_theme_mod( 'ruki_category_featured_num', 3 ),
			    'cat' => $category->term_id,
			    'meta_key' => 'ruki_featured_post', // Featured Posts
				'meta_value' => 1,
				'post_status' => array(      
					'publish', // A published post or page.
					),

			);

			$posts_query = new WP_Query( $query_args );

			if( $posts_query->have_posts( ) )  {
				$post_ids = wp_list_pluck( $posts_query->posts, 'ID' );
				// Save the results in a transient for 24 hours (always set NEW transient after post or customizer update)
				set_transient( 'ruki_category_' . $category->term_id . '_featured', $posts_query, 24 * HOUR_IN_SECONDS );
				if ( get_theme_mod( 'ruki_category_featured_exclude_duplicate', false ) ) {
					set_transient( 'ruki_category_' . $category->term_id . '_featured_exclude_ids', $post_ids, 24 * HOUR_IN_SECONDS );
				}

			} else {
				delete_transient( 'ruki_category_' . $category->term_id . '_featured' );
			}

		}

	}

}

add_action( 'save_post', 'ruki_category_featured_set_transient', 20 );
add_action( 'customize_save_after', 'ruki_category_featured_set_transient', 20 );

// ========================================================
// Exclude Posts from category/archive loop
// ========================================================

function ruki_exclude_category_featured_posts( $query ) {

	if ( is_category() ) {

		$category = get_queried_object();

		$exclude_ids = get_transient( 'ruki_category_' . $category->term_id . '_featured_exclude_ids' );

	}

	/**
	 * Is archive
	 * Is Main Query
	 * Is TRUE remove posts
	 */

    if ( $query->is_category() && $query->is_main_query() && get_theme_mod( 'ruki_category_featured', true ) && get_theme_mod( 'ruki_category_featured_exclude_duplicate', false ) ) {
        $query->set( 'post__not_in', $exclude_ids );
    }
}

add_action( 'pre_get_posts', 'ruki_exclude_category_featured_posts' );



?>